@@ -1,8 +1,7 @@
-from pytz import timezone
-
 from .filters import ConditionsMixin
 from django_forest.utils import get_token
 from django_forest.utils.scope import ScopeManager
+from django_forest.utils.date import get_timezone
 
 
 class ScopeMixin(ConditionsMixin):
@@ -10,5 +9,5 @@ class ScopeMixin(ConditionsMixin):
         token = get_token(request)
         filters = ScopeManager.get_scope_for_user(token, Model._meta.db_table)
         if filters is not None:
-            tz = timezone(request.GET['timezone'])
+            tz = get_timezone(request.GET['timezone'])
             return self.handle_aggregator(filters, Model, tz)
